"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.config = void 0;
const CONFIG_DIR = `${process.env.HOME}/.wormhole`;
const CONFIG_FILE = `${CONFIG_DIR}/default.json`;
process.env["NODE_CONFIG_DIR"] = CONFIG_DIR;
process.env["SUPPRESS_NO_CONFIG_WARNING"] = "y";
const config_1 = __importDefault(require("config"));
const fs_1 = __importDefault(require("fs"));
const defaultConfig = {
    wormholeDir: computeRepoRootPath(),
};
/**
 * Global config object.
 * Importing this module will read the config file and update it if necessary.
 */
exports.config = readAndUpdateConfig();
// Computes the path to the root of the wormhole repository based on the
// location of this file (well, the compiled version of this file).
function computeRepoRootPath() {
    let rel = "/clients/js/build/config.js";
    // check if mainPath matches $DIR/clients/js/build/config.js
    if (__filename.endsWith(rel)) {
        // if so, grab $DIR from mainPath
        return __filename.substring(0, __filename.length - rel.length);
    }
    else {
        // otherwise, throw an error
        throw new Error(`Could not compute repo root path for ${__filename}`);
    }
}
function readAndUpdateConfig() {
    if (exports.config !== undefined) {
        return exports.config;
    }
    let conf = defaultConfig;
    // iterate through all the keys in defaultConfig
    for (const key in conf) {
        // if the key is not in config, set it to the default value
        if (config_1.default.has(key)) {
            conf[key] = config_1.default.get(key);
        }
    }
    let json_conf = JSON.stringify(conf, null, 2) + "\n";
    // if the config file does not exist or does not have some of the default
    // values, create/update it
    let write = false;
    if (!fs_1.default.existsSync(CONFIG_FILE)) {
        console.error('\x1b[33m%s\x1b[0m', `NOTE: Created config file at ${CONFIG_FILE}`);
        write = true;
    }
    else if (json_conf !== fs_1.default.readFileSync(CONFIG_FILE, "utf8")) {
        // ^ this will also normalise the config file, but the main thing is
        // that it writes out defaults if they are missing
        console.error('\x1b[33m%s\x1b[0m', `NOTE: Updated config file at ${CONFIG_FILE}`);
        write = true;
    }
    if (write) {
        if (!fs_1.default.existsSync(CONFIG_DIR)) {
            fs_1.default.mkdirSync(CONFIG_DIR, { recursive: true });
        }
        fs_1.default.writeFileSync(CONFIG_FILE, json_conf);
    }
    return conf;
}
